==> haskell-wai-app-static-3.1.6.3-111-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.3
id: wai-app-static-3.1.6.3-KlMtenWI5Gc9UfLVOWyOh1
key: wai-app-static-3.1.6.3-KlMtenWI5Gc9UfLVOWyOh1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
abi: 28c98e3ae75469fd81a2f04f7212c961
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-app-static-3.1.6.3
hs-libraries: HSwai-app-static-3.1.6.3-KlMtenWI5Gc9UfLVOWyOh1
depends:
    base-4.12.0.0 blaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 http-date-0.0.8-FeUlqVvLix9AYQegtQM16i
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
    warp-3.3.3-3pDLRnq84vs8OTjQ6RThJz
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.3-112-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.3
id: wai-app-static-3.1.6.3-I5HsGVSst2o6o0wH91rrNF
key: wai-app-static-3.1.6.3-I5HsGVSst2o6o0wH91rrNF
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
abi: b310fe954bab3d2c2a5d244095e9a50c
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-app-static-3.1.6.3
hs-libraries: HSwai-app-static-3.1.6.3-I5HsGVSst2o6o0wH91rrNF
depends:
    base-4.12.0.0 blaze-html-0.9.1.2-LFnllGMPezqEutot32d3pA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 http-date-0.0.8-FeUlqVvLix9AYQegtQM16i
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
    warp-3.3.4-5ShbJ37FdmDIGscrQqPA9F
    zlib-0.6.2.1-Aknvu72a6qHHNTLcHtkXd
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
